@@ -21,4 +21,4 @@ Boston, MA 02110-1301 USA
 
 def guake_version():
     # Do not import in the module root to speed up the dbus communication as much as possible
-    return pbr.version.VersionInfo('guake').version_string()
+    return '3.0.4'
